Pyskool documentation — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- Pyskool 1.1.1 documentation »

# Pyskool documentation

- What is Pyskool?
- Installing and running Pyskool
- Playing Pyskool
- Example customisations
- General info
- Changelog

# Technical reference

- Graphics
- Main ini file
- Game ini files
- Commands

# API documentation

- Index
- Module Index

### Navigation

- index
- modules |
- next |
- Pyskool 1.1.1 documentation »